@@ -9,12 +9,15 @@ Usage:
 """
 # future division is important to divide integers and get as
 # a result precise floating numbers (instead of truncated int)
-from __future__ import division, absolute_import
+from __future__ import absolute_import, division
+
 # import compatibility functions and utilities
+import re
 import sys
-from .utils import _range
+
 # to inherit from the tqdm class
 from .std import tqdm as std_tqdm
+from .utils import _range
 
 if True:  # pragma: no cover
     # import IPython/Jupyter base widget and display utilities
@@ -40,17 +43,19 @@ if True:  # pragma: no cover
 
     try:  # IPython 4.x / 3.x
         if IPY == 32:
+            from IPython.html.widgets import HTML
             from IPython.html.widgets import FloatProgress as IProgress
-            from IPython.html.widgets import HBox, HTML
+            from IPython.html.widgets import HBox
             IPY = 3
         else:
+            from ipywidgets import HTML
             from ipywidgets import FloatProgress as IProgress
-            from ipywidgets import HBox, HTML
+            from ipywidgets import HBox
     except ImportError:
         try:  # IPython 2.x
-            from IPython.html.widgets import FloatProgressWidget as IProgress
-            from IPython.html.widgets import ContainerWidget as HBox
             from IPython.html.widgets import HTML
+            from IPython.html.widgets import ContainerWidget as HBox
+            from IPython.html.widgets import FloatProgressWidget as IProgress
             IPY = 2
         except ImportError:
             IPY = 0
@@ -77,9 +82,7 @@ class TqdmHBox(HBox):
     def _repr_json_(self, pretty=None):
         if not hasattr(self, "pbar"):
             return {}
-        d = dict(self.pbar.format_dict,
-                 bar_format=(self.pbar.format_dict['bar_format']
-                             or "{l_bar}{bar}{r_bar}").replace("<bar/>", "{bar}"))
+        d = self.pbar.format_dict
         if pretty is not None:
             d["ascii"] = not pretty
         return d
@@ -145,13 +148,6 @@ class tqdm_notebook(std_tqdm):
 
         return container
 
-    @staticmethod
-    def format_meter(n, total, *args, **kwargs):
-        if total and kwargs.get('bar_format', None) is None:
-            kwargs = kwargs.copy()
-            kwargs['bar_format'] = "{l_bar}<bar/>{r_bar}"
-        return std_tqdm.format_meter(n, total, *args, **kwargs)
-
     def display(self, msg=None, pos=None,
                 # additional signals
                 close=False, bar_style=None):
@@ -163,7 +159,11 @@ class tqdm_notebook(std_tqdm):
         # clear_output(wait=1)
 
         if not msg and not close:
-            msg = self.__repr__()
+            d = self.format_dict
+            # remove {bar}
+            d['bar_format'] = (d['bar_format'] or "{l_bar}<bar/>{r_bar}").replace(
+                "{bar}", "<bar/>")
+            msg = self.format_meter(**d)
 
         ltext, pbar, rtext = self.container.children
         pbar.value = self.n
@@ -171,16 +171,10 @@ class tqdm_notebook(std_tqdm):
         if msg:
             # html escape special characters (like '&')
             if '<bar/>' in msg:
-                left, right = map(escape, msg.split('<bar/>', 1))
+                left, right = map(escape, re.split(r'\|?<bar/>\|?', msg, 1))
             else:
                 left, right = '', escape(msg)
 
-            # remove inesthetical pipes
-            if left and left[-1] == '|':
-                left = left[:-1]
-            if right and right[0] == '|':
-                right = right[1:]
-
             # Update description
             ltext.value = left
             # never clear the bar (signal: msg='')
@@ -191,7 +185,7 @@ class tqdm_notebook(std_tqdm):
         if bar_style:
             # Hack-ish way to avoid the danger bar_style being overridden by
             # success because the bar gets closed after the error...
-            if not (pbar.bar_style == 'danger' and bar_style == 'success'):
+            if pbar.bar_style != 'danger' or bar_style != 'success':
                 pbar.bar_style = bar_style
 
         # Special signal to close the bar
@@ -228,8 +222,6 @@ class tqdm_notebook(std_tqdm):
 
         # Initialize parent class + avoid printing by using gui=True
         kwargs['gui'] = True
-        if 'bar_format' in kwargs:
-            kwargs['bar_format'] = kwargs['bar_format'].replace('{bar}', '<bar/>')
         # convert disable = None to False
         kwargs['disable'] = bool(kwargs.get('disable', False))
         colour = kwargs.pop('colour', None)
